# Generated by Django 4.0.2 on 2022-05-10 07:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('telescoop_auth', '0002_alter_user_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='is_superuser',
            field=models.BooleanField(default=False),
        ),
    ]
